@@ -337,15 +337,15 @@ print_output (GnomeRROutputInfo *info)
 {
         int x, y, width, height;
 
-        g_print ("  Output: %s attached to %s\n", gnome_rr_output_info_get_display_name (info), gnome_rr_output_info_get_name (info));
-        g_print ("     status: %s\n", gnome_rr_output_info_is_active (info) ? "on" : "off");
+        g_debug ("  Output: %s attached to %s", gnome_rr_output_info_get_display_name (info), gnome_rr_output_info_get_name (info));
+        g_debug ("     status: %s", gnome_rr_output_info_is_active (info) ? "on" : "off");
 
         gnome_rr_output_info_get_geometry (info, &x, &y, &width, &height);
-        g_print ("     width: %d\n", width);
-        g_print ("     height: %d\n", height);
-        g_print ("     rate: %d\n", gnome_rr_output_info_get_refresh_rate (info));
-        g_print ("     primary: %s\n", gnome_rr_output_info_get_primary (info) ? "true" : "false");
-        g_print ("     position: %d %d\n", x, y);
+        g_debug ("     width: %d", width);
+        g_debug ("     height: %d", height);
+        g_debug ("     rate: %d", gnome_rr_output_info_get_refresh_rate (info));
+        g_debug ("     primary: %s", gnome_rr_output_info_get_primary (info) ? "true" : "false");
+        g_debug ("     position: %d %d", x, y);
 }
 
 static void
@@ -354,13 +354,13 @@ print_configuration (GnomeRRConfig *config, const char *header)
         int i;
         GnomeRROutputInfo **outputs;
 
-        g_print ("=== %s Configuration ===\n", header);
+        g_debug ("=== %s Configuration ===", header);
         if (!config) {
-                g_print ("  none\n");
+                g_debug ("  none");
                 return;
         }
 
-        g_print ("  Clone: %s\n", gnome_rr_config_get_clone (config) ? "true" : "false");
+        g_debug ("  Clone: %s", gnome_rr_config_get_clone (config) ? "true" : "false");
 
         outputs = gnome_rr_config_get_outputs (config);
         for (i = 0; outputs[i] != NULL; ++i)
@@ -880,6 +880,8 @@ make_clone_setup (GsdXrandrManager *manager, GnomeRRScreen *screen)
                 return NULL;
 
         result = gnome_rr_config_new_current (screen, NULL);
+        gnome_rr_config_set_clone (result, TRUE);
+
         outputs = gnome_rr_config_get_outputs (result);
 
         for (i = 0; outputs[i] != NULL; ++i) {
@@ -921,8 +923,6 @@ make_clone_setup (GsdXrandrManager *manager, GnomeRRScreen *screen)
                 result = NULL;
         }
 
-        gnome_rr_config_set_clone (result, TRUE);
-
         print_configuration (result, "clone setup");
 
         return result;
@@ -1004,6 +1004,8 @@ make_laptop_setup (GsdXrandrManager *manager, GnomeRRScreen *screen)
         GnomeRROutputInfo **outputs = gnome_rr_config_get_outputs (result);
         int i;
 
+        gnome_rr_config_set_clone (result, FALSE);
+
         for (i = 0; outputs[i] != NULL; ++i) {
                 GnomeRROutputInfo *info = outputs[i];
 
@@ -1019,13 +1021,12 @@ make_laptop_setup (GsdXrandrManager *manager, GnomeRRScreen *screen)
                 }
         }
 
+
         if (config_is_all_off (result)) {
                 g_object_unref (G_OBJECT (result));
                 result = NULL;
         }
 
-        gnome_rr_config_set_clone (result, FALSE);
-
         print_configuration (result, "Laptop setup");
 
         /* FIXME - Maybe we should return NULL if there is more than
@@ -1146,6 +1147,8 @@ make_xinerama_setup (GsdXrandrManager *manager, GnomeRRScreen *screen)
         int i;
         int x;
 
+        gnome_rr_config_set_clone (result, FALSE);
+
         x = 0;
         for (i = 0; outputs[i] != NULL; ++i) {
                 GnomeRROutputInfo *info = outputs[i];
@@ -1174,8 +1177,6 @@ make_xinerama_setup (GsdXrandrManager *manager, GnomeRRScreen *screen)
                 result = NULL;
         }
 
-        gnome_rr_config_set_clone (result, FALSE);
-
         print_configuration (result, "xinerama setup");
 
         return result;
@@ -1192,6 +1193,8 @@ make_other_setup (GnomeRRScreen *screen)
         GnomeRROutputInfo **outputs = gnome_rr_config_get_outputs (result);
         int i;
 
+        gnome_rr_config_set_clone (result, FALSE);
+
         for (i = 0; outputs[i] != NULL; ++i) {
                 GnomeRROutputInfo *info = outputs[i];
 
@@ -1209,8 +1212,6 @@ make_other_setup (GnomeRRScreen *screen)
                 result = NULL;
         }
 
-        gnome_rr_config_set_clone (result, FALSE);
-
         print_configuration (result, "other setup");
 
         return result;
@@ -1727,7 +1728,7 @@ auto_configure_outputs (GsdXrandrManager *manager, guint32 timestamp)
 {
         GnomeRRConfig *config;
 
-        g_debug ("xrandr auto-configure\n");
+        g_debug ("xrandr auto-configure");
         config = make_default_setup (manager);
         if (config) {
                 apply_configuration (manager, config, timestamp, TRUE, FALSE);
